pub trait FromOtherOption<O: OptionNumber> {
    type Error;

    fn convert_from_other(other: O) -> Result<Self, Self::Error>
   where
        Self: Sized
; }
Experimental trait for conversion between option representation, with the goal to later avoid the conversion step via u16 and specialize for T->T conversions.

Required Associated Types

Required Methods

Implementors